==> FHLBBS-4.2.tgz: maple/config.h <==
/*-------------------------------------------------------*/
/* config.h     ( NTHU CS MapleBBS Ver 2.36 )            */
/*-------------------------------------------------------*/
/* target : site-configurable settings                   */
/* create : 95/03/29                                     */
/* update : 95/12/15                                     */
/*-------------------------------------------------------*/

#ifndef _CONFIG_H_
#define _CONFIG_H_

/* ----------------------------------------------------- */
/* wq BBS W}                                     */
/* ------------------------------------------------------*/

#define BOARDNAME       "HRBBS"                /* 寸W */
#define BBSNAME         "FHL-BBS"               /* ^寸W */
#define MYHOSTNAME      "bbs.fhl.net"    /* } */
#define MYVERSION       "Maple BBS 2.36"        /* { */
#define MYBBSID         "fhl-bbs"                /* HNX */
#define BBSHOME         "/home/bbs"             /* BBS a */
#define BBSUSER         "bbs"
#define BBSUID          9999
#define BBSGID          999
#define BBSSHELL        "/home/bbs/bin/bbsrf"           /* eݵ{ */
#define BBSPROG         "/home/bbs/bin/bbs"             /* D{ */


/* ----------------------------------------------------- */
/* պAW                                              */
/* ------------------------------------------------------*/

#define WITHOUT_CHROOT          /* ݭn root set-uid */

#define HAVE_MOVIE              /* ܰʺAiܪO */

#undef  HAVE_INFO               /* ܵ{ */

#undef  HAVE_License            /*  GNU ve */

#define INTERNET_PRIVATE_EMAIL  /* iHHpHH Internet */

#define BIT8                    /* 䴩t */

#define DEFAULTBOARD   "sysop"  /* w]ݪO */

#define LOGINATTEMPTS   (3)     /* ̤ji~ */

#define LOGINASNEW      (1)     /* ĥΤWӽбb */

#define VOTE            (1)     /* ѧ벼\ */

#define INTERNET_EMAIL          /* 䴩 InterNet Email \(t Forward) */

#undef  EMAIL_JUSTIFY           /* oX InterNet Email {ҫH */

#undef  NEWUSER_LIMIT           /* sWTѭ */

#undef INVISIBLE               /*  BBS user ӦۦB */

#define MULTI_LOGINS            /* \PɦhW */

#undef  POSTBUG                 /* board/mail post S bug F */

#undef  HAVE_REPORT             /* tΰlܳi */

#define INITIAL_SETUP           /* }A٨Sإ߹w]ݪO[SYSOP] */

#define HAVE_MMAP               /* ĥ mmap(): memory mapped I/O */
                                /* b SunOSBFreeBSD WiH[t 30  */

#define HAVE_ORIGIN             /*  author ӦۦB */

#undef  HAVE_MAILCLEAN          /* MzҦϥΪ̭ӤHHc */

#undef HAVE_SUICIDE            /* ѨϥΪ̦۱\ */

#define HAVE_ANONYMOUS         /*ѰΦWO\*/

/* ----------------------------------------------------- */
/* H BBS WҦXW                               */
/* ----------------------------------------------------- */

#define MAXUSERS        (16000)         /* ̰UH */

#define MAXBOARD        (256)           /* ̤j}Ӽ */

#define MAXACTIVE       (256)           /* ̦hPɤWH */

#define MAX_FRIEND      (128)           /* J cache ̦hBͼƥ */

#define MAX_REJECT      (32)            /* J cache ̦haHƥ */


/* ----------------------------------------------------- */
/* LtΤWѼ                                      */
/* ----------------------------------------------------- */


#define MAXKEEPMAIL     (200)           /* ̦hOdX MAILH */

#define MAX_NOTE        (10)            /* ̦hOdXgdH */

#define MAXSIGLINES     (8)             /* ñWɤޤJ̤j */

#define MAXQUERYLINES   (16)            /*  Query/Plan T̤j */

#define MAXPAGES        (256)           /* more.c 峹ƤW (lines/22) */

#define MAXMSGS         (10)            /* y(T)ԭ@W */

#define MOVIE_INT       (40)            /* ʵegɶG40 */

#define noGrp				/*ΰQװϦbCXҦboardɤCX*/

/* ----------------------------------------------------- */
/* obL[۰ñh                                      */
/* ------------------------------------------------------*/

#define DOTIMEOUT

#ifdef  DOTIMEOUT
#define IDLE_TIMEOUT    (60*30)         /* @뱡p timeout */
#define MONITOR_TIMEOUT (60*40)          /* monitor ɤ timeout */
#define SHOW_IDLE_TIME                  /* ܶmɶ */
#endif


/* ----------------------------------------------------- */
/* chat.c & xchatd.c ĥΪ port  protocol           */
/* ------------------------------------------------------*/

#define CHATPORT        5722
#define MAXROOM         16              /* ̦hX][H */

#define EXIT_LOGOUT     0
#define EXIT_LOSTCONN   -1
#define EXIT_CLIERROR   -2
#define EXIT_TIMEDOUT   -3
#define EXIT_KICK       -4

#define CHAT_LOGIN_OK       "OK"
#define CHAT_LOGIN_EXISTS   "EX"
#define CHAT_LOGIN_INVALID  "IN"
#define CHAT_LOGIN_BOGUS    "BG"

#define BADCIDCHARS " *"        /* Chat Room TΩ nick r */


/* ----------------------------------------------------- */
/* tΰѼ                                              */
/* ----------------------------------------------------- */

#define MAGIC_KEY       5782    /* {ҫHsX */

#define BRDSHM_KEY      1215
#define UIDSHM_KEY      1217
#define UTMPSHM_KEY     1219


/* ----------------------------------------------------- */
/* ӽбbɭnDӽЪ̯u                          */
/* ----------------------------------------------------- */

#define SHOWUID                 /* ݨϥΪ UID */
#define SHOWTTY                 /* ݨϥΪ TTY */
#define SHOWPID                 /* ݨϥΪ PID */

#define REALINFO                /* umW */

#ifdef  REALINFO
#undef  ACTS_REALNAMES          /* Dؿ (U)ser ܯumW */
#undef  POST_REALNAMES          /* KɪWumW */
#undef  MAIL_REALNAMES          /* HHɪWumW */
#undef  QUERY_REALNAMES         /* Q Query  User iumW */
#endif


/* ----------------------------------------------------- */
/* ѥ~{                                          */
/* ----------------------------------------------------- */

#define HAVE_EXTERNAL

#ifdef  HAVE_EXTERNAL
#undef  HAVE_TIN        /*  news reader */
#undef  HAVE_GOPHER     /*  gopher */
#define HAVE_WWW        /*  www browser */
#define HAVE_ON_LINE     /*  online bible */
#define HAVE_RBIBLE     /*  tgtŪ */
#define HAVE_BOOK      /*  ϮѸ */
#undef  HAVE_BBSDOORS   /*  bbs doors */
#undef  HAVE_GAME       /* ѺsuC */
#undef  HAVE_ADM_SHELL  /*  csh HK޲z */
#endif


#endif

==> FHLBBS-5.3.tgz: maple/config.h <==
/*-------------------------------------------------------*/
/* config.h     ( NTHU CS MapleBBS Ver 2.36 )            */
/*-------------------------------------------------------*/
/* target : site-configurable settings                   */
/* create : 95/03/29                                     */
/* update : 95/12/15                                     */
/*-------------------------------------------------------*/

#ifndef _CONFIG_H_
#define _CONFIG_H_

/* ----------------------------------------------------- */
/* wq BBS W}                                     */
/* ------------------------------------------------------*/

#define BOARDNAME       "HRBBS"                /* 寸W */
#define BBSNAME         "FHL-BBS"               /* ^寸W */
#define MYHOSTNAME      "bbs.fhl.net"    /* } */
#define MYVERSION       "Maple BBS 2.36"        /* { */
#define MYBBSID         "fhl-bbs"                /* HNX */
#define BBSHOME         "/home/bbs"             /* BBS a */
#define BBSUSER         "bbs"
#define BBSUID          9999
#define BBSGID          999
#define BBSSHELL        "/home/bbs/bin/bbsrf"           /* eݵ{ */
#define BBSPROG         "/home/bbs/bin/bbs"             /* D{ */


/* ----------------------------------------------------- */
/* պAW                                              */
/* ------------------------------------------------------*/

#define WITHOUT_CHROOT          /* ݭn root set-uid */

#define HAVE_MOVIE              /* ܰʺAiܪO */

#undef  HAVE_INFO               /* ܵ{ */

#define  HAVE_License            /*  GNU ve */

#define INTERNET_PRIVATE_EMAIL  /* iHHpHH Internet */

#define BIT8                    /* 䴩t */

#define DEFAULTBOARD   "sysop"  /* w]ݪO */

#define LOGINATTEMPTS   (3)     /* ̤ji~ */

#define LOGINASNEW      (1)     /* ĥΤWӽбb */

#define VOTE            (1)     /* ѧ벼\ */

#define INTERNET_EMAIL          /* 䴩 InterNet Email \(t Forward) */

#undef  EMAIL_JUSTIFY           /* oX InterNet Email {ҫH */

#undef  NEWUSER_LIMIT           /* sWTѭ */

#undef INVISIBLE               /*  BBS user ӦۦB */

#define MULTI_LOGINS            /* \PɦhW */

#undef  POSTBUG                 /* board/mail post S bug F */

#undef  HAVE_REPORT             /* tΰlܳi */

#define INITIAL_SETUP           /* }A٨Sإ߹w]ݪO[SYSOP] */

#define HAVE_MMAP               /* ĥ mmap(): memory mapped I/O */
                                /* b SunOSBFreeBSD WiH[t 30  */

#define HAVE_ORIGIN             /*  author ӦۦB */

#undef  HAVE_MAILCLEAN          /* MzҦϥΪ̭ӤHHc */

#undef HAVE_SUICIDE            /* ѨϥΪ̦۱\ */

#define HAVE_ANONYMOUS         /*ѰΦWO\*/

/* ----------------------------------------------------- */
/* H BBS WҦXW                               */
/* ----------------------------------------------------- */

#define MAXUSERS        (16000)         /* ̰UH */

#define MAXBOARD        (256)           /* ̤j}Ӽ */

#define MAXACTIVE       (256)           /* ̦hPɤWH */

#define MAX_FRIEND      (128)           /* J cache ̦hBͼƥ */

#define MAX_REJECT      (32)            /* J cache ̦haHƥ */


/* ----------------------------------------------------- */
/* LtΤWѼ                                      */
/* ----------------------------------------------------- */


#define MAXKEEPMAIL     (200)           /* ̦hOdX MAILH */

#define MAX_NOTE        (10)            /* ̦hOdXgdH */

#define MAXSIGLINES     (8)             /* ñWɤޤJ̤j */

#define MAXQUERYLINES   (16)            /*  Query/Plan T̤j */

#define MAXPAGES        (256)           /* more.c 峹ƤW (lines/22) */

#define MAXMSGS         (10)            /* y(T)ԭ@W */

#define MOVIE_INT       (40)            /* ʵegɶG40 */

#define noGrp				/*ΰQװϦbCXҦboardɤCX*/

/* ----------------------------------------------------- */
/* obL[۰ñh                                      */
/* ------------------------------------------------------*/

#define DOTIMEOUT

#ifdef  DOTIMEOUT
#define IDLE_TIMEOUT    (60*30)         /* @뱡p timeout */
#define MONITOR_TIMEOUT (60*40)          /* monitor ɤ timeout */
#define SHOW_IDLE_TIME                  /* ܶmɶ */
#endif


/* ----------------------------------------------------- */
/* chat.c & xchatd.c ĥΪ port  protocol           */
/* ------------------------------------------------------*/

#define CHATPORT        5722
#define MAXROOM         16              /* ̦hX][H */

#define EXIT_LOGOUT     0
#define EXIT_LOSTCONN   -1
#define EXIT_CLIERROR   -2
#define EXIT_TIMEDOUT   -3
#define EXIT_KICK       -4

#define CHAT_LOGIN_OK       "OK"
#define CHAT_LOGIN_EXISTS   "EX"
#define CHAT_LOGIN_INVALID  "IN"
#define CHAT_LOGIN_BOGUS    "BG"

#define BADCIDCHARS " *"        /* Chat Room TΩ nick r */


/* ----------------------------------------------------- */
/* tΰѼ                                              */
/* ----------------------------------------------------- */

#define MAGIC_KEY       5782    /* {ҫHsX */

#define BRDSHM_KEY      1215
#define UIDSHM_KEY      1217
#define UTMPSHM_KEY     1219


/* ----------------------------------------------------- */
/* ӽбbɭnDӽЪ̯u                          */
/* ----------------------------------------------------- */

#define SHOWUID                 /* ݨϥΪ UID */
#define SHOWTTY                 /* ݨϥΪ TTY */
#define SHOWPID                 /* ݨϥΪ PID */

#define REALINFO                /* umW */

#ifdef  REALINFO
#undef  ACTS_REALNAMES          /* Dؿ (U)ser ܯumW */
#undef  POST_REALNAMES          /* KɪWumW */
#undef  MAIL_REALNAMES          /* HHɪWumW */
#undef  QUERY_REALNAMES         /* Q Query  User iumW */
#endif


/* ----------------------------------------------------- */
/* ѥ~{                                          */
/* ----------------------------------------------------- */

#define HAVE_EXTERNAL

#ifdef  HAVE_EXTERNAL
#undef  HAVE_TIN        /*  news reader */
#undef  HAVE_GOPHER     /*  gopher */
#define HAVE_WWW        /*  www browser */
#define HAVE_ON_LINE     /*  online bible */
#define HAVE_RBIBLE     /*  tgtŪ */
#undef HAVE_BOOK      /*  ϮѸ */
#undef  HAVE_BBSDOORS   /*  bbs doors */
#undef  HAVE_GAME       /* ѺsuC */
#undef  HAVE_ADM_SHELL  /*  csh HK޲z */
#endif


#endif
